@@ -454,6 +454,7 @@ class AMcardsClient:
         shipping_address: dict,
         return_address: dict = None,
         send_date: str = None,
+        message: str = None,
     ) -> CardResponse:
         """Attempt to send a card.
 
@@ -518,10 +519,12 @@ class AMcardsClient:
                 }
 
         :param Optional[str] send_date: The date the card should be sent. If not specified, the card will be scheduled for the following day. The format should be: ``"YYYY-MM-DD"``.
+        :param Optional[str] message: A message to add to the card. This will be added to the inside bottom or inside right panel on the card and will not replace any message that is currently on the template.
 
         :return: AMcards' :py:class:`response <amcards.models.CardResponse>` for sending a single card.
         :rtype: :py:class:`CardResponse <amcards.models.CardResponse>`
 
+        :raises CardSendError: When something goes wrong when attempting to send a card.
         :raises AuthenticationError: When the client's ``access_token`` is invalid.
         :raises ForbiddenTemplateError: When the client does not own the :py:class:`template <amcards.models.Template>` specified by ``template_id``.
         :raises ShippingAddressError: When ``shipping_address`` is missing some `required` keys.
@@ -559,6 +562,9 @@ class AMcardsClient:
         if send_date is not None:
             body |= {'send_date': send_date}
 
+        if message is not None:
+            body |= {'message': message}
+
         res = requests.post(f'{DOMAIN}/cards/open-card-form-oa/', json=body, headers=self.HEADERS)
 
         # Check for errors
@@ -787,6 +793,7 @@ class AMcardsClient:
         :return: AMcards' :py:class:`response <amcards.models.CampaignResponse>` for sending a single drip campaign.
         :rtype: :py:class:`CampaignResponse <amcards.models.CampaignResponse>`
 
+        :raises CampaignSendError: When something goes wrong when attempting to send a drip campaign.
         :raises AuthenticationError: When the client's ``access_token`` is invalid.
         :raises ForbiddenCampaignError: When the client does not own the :py:class:`campaign <amcards.models.Campaign>` specified by ``campaign_id``.
         :raises ShippingAddressError: When ``shipping_address`` is missing some `required` keys.
@@ -959,6 +966,7 @@ class AMcardsClient:
         :return: AMcards' :py:class:`response <amcards.models.CardsResponse>` for sending multiple cards.
         :rtype: :py:class:`CardsResponse <amcards.models.CardsResponse>`
 
+        :raises CardsSendError: When something goes wrong when attempting to send cards.
         :raises AuthenticationError: When the client's ``access_token`` is invalid.
         :raises ForbiddenTemplateError: When the client does not own the :py:class:`template <amcards.models.Template>` specified by ``template_id``.
         :raises ShippingAddressError: When some items in ``shipping_addresses`` are missing some `required` keys.
